aboutsummaryrefslogtreecommitdiffstats
path: root/resources/tools/dash/app/pal/trending/layout.py
diff options
context:
space:
mode:
Diffstat (limited to 'resources/tools/dash/app/pal/trending/layout.py')
-rw-r--r--resources/tools/dash/app/pal/trending/layout.py106
1 files changed, 52 insertions, 54 deletions
diff --git a/resources/tools/dash/app/pal/trending/layout.py b/resources/tools/dash/app/pal/trending/layout.py
index 55d0d08e83..c21e4b3c2e 100644
--- a/resources/tools/dash/app/pal/trending/layout.py
+++ b/resources/tools/dash/app/pal/trending/layout.py
@@ -578,6 +578,34 @@ class Layout:
]
),
dbc.Row(
+ id="row-ctrl-normalize",
+ class_name="gy-1",
+ children=[
+ dbc.Label(
+ children=self._show_tooltip(
+ "help-normalize", "Normalize"),
+ class_name="p-0"
+ ),
+ dbc.Col(
+ children=[
+ dbc.Checklist(
+ id="cl-ctrl-normalize",
+ options=[{
+ "value": "normalize",
+ "label": (
+ "Normalize results to CPU"
+ "frequency 2GHz"
+ )
+ }],
+ value=[],
+ inline=True,
+ switch=False
+ ),
+ ]
+ )
+ ]
+ ),
+ dbc.Row(
class_name="gy-1 p-0",
children=[
dbc.ButtonGroup(
@@ -698,6 +726,7 @@ class Layout:
"cl-ctrl-testtype-all-value": list(),
"cl-ctrl-testtype-all-options": CL_ALL_DISABLED,
"btn-ctrl-add-disabled": True,
+ "cl-normalize-value": list(),
"cl-selected-options": list(),
}
@@ -850,6 +879,7 @@ class Layout:
Output("cl-ctrl-testtype-all", "value"),
Output("cl-ctrl-testtype-all", "options"),
Output("btn-ctrl-add", "disabled"),
+ Output("cl-ctrl-normalize", "value"),
Output("cl-selected", "options"), # User selection
State("control-panel", "data"), # Store
State("selected-tests", "data"), # Store
@@ -864,6 +894,7 @@ class Layout:
Input("cl-ctrl-framesize-all", "value"),
Input("cl-ctrl-testtype", "value"),
Input("cl-ctrl-testtype-all", "value"),
+ Input("cl-ctrl-normalize", "value"),
Input("btn-ctrl-add", "n_clicks"),
Input("dpr-period", "start_date"),
Input("dpr-period", "end_date"),
@@ -874,8 +905,8 @@ class Layout:
def _update_ctrl_panel(cp_data: dict, store_sel: list, list_sel: list,
dd_dut: str, dd_phy: str, dd_area: str, dd_test: str, cl_core: list,
cl_core_all: list, cl_framesize: list, cl_framesize_all: list,
cl_testtype: list, cl_testtype_all: list, btn_add: int,
d_start: str, d_end: str, btn_remove: int,
btn_remove_all: int, href: str) -> tuple:
"""
"""
@@ -1153,22 +1184,6 @@ class Layout:
row_btns_sel_tests = self.STYLE_ENABLED
if self.CLEAR_ALL_INPUTS:
ctrl_panel.set(ctrl_panel.defaults)
- ctrl_panel.set({
- "cl-selected-options": self._list_tests(store_sel)
- })
- row_fig_tput, row_fig_lat, row_btn_dwnld = \
- _generate_plotting_area(
- graph_trending(self.data, store_sel, self.layout,
- d_start, d_end),
- _gen_new_url(parsed_url, store_sel, d_start, d_end)
- )
- elif trigger_id == "dpr-period":
- row_fig_tput, row_fig_lat, row_btn_dwnld = \
- _generate_plotting_area(
- graph_trending(self.data, store_sel, self.layout,
- d_start, d_end),
- _gen_new_url(parsed_url, store_sel, d_start, d_end)
- )
elif trigger_id == "btn-sel-remove-all":
_ = btn_remove_all
row_fig_tput = self.PLACEHOLDER
@@ -1186,11 +1201,25 @@ class Layout:
if item["id"] not in list_sel:
new_store_sel.append(item)
store_sel = new_store_sel
+ elif trigger_id == "url":
+ # TODO: Add verification
+ url_params = parsed_url["params"]
+ if url_params:
+ store_sel = literal_eval(
+ url_params.get("store_sel", list())[0])
+ d_start = self._get_date(url_params.get("start", list())[0])
+ d_end = self._get_date(url_params.get("end", list())[0])
+ if store_sel:
+ row_card_sel_tests = self.STYLE_ENABLED
+ row_btns_sel_tests = self.STYLE_ENABLED
+
+ if trigger_id in ("btn-ctrl-add", "url", "dpr-period"
+ "btn-sel-remove", "cl-ctrl-normalize"):
if store_sel:
row_fig_tput, row_fig_lat, row_btn_dwnld = \
_generate_plotting_area(
graph_trending(self.data, store_sel, self.layout,
- d_start, d_end),
+ d_start, d_end, bool(cl_normalize)),
_gen_new_url(parsed_url, store_sel, d_start, d_end)
)
ctrl_panel.set({
@@ -1204,40 +1233,6 @@ class Layout:
row_btns_sel_tests = self.STYLE_DISABLED
store_sel = list()
ctrl_panel.set({"cl-selected-options": list()})
- elif trigger_id == "url":
- # TODO: Add verification
- url_params = parsed_url["params"]
- if url_params:
- store_sel = literal_eval(
- url_params.get("store_sel", list())[0])
- d_start = self._get_date(url_params.get("start", list())[0])
- d_end = self._get_date(url_params.get("end", list())[0])
- if store_sel:
- row_fig_tput, row_fig_lat, row_btn_dwnld = \
- _generate_plotting_area(
- graph_trending(
- self.data, store_sel, self.layout, d_start,
- d_end
- ),
- _gen_new_url(
- parsed_url, store_sel, d_start, d_end
- )
- )
- row_card_sel_tests = self.STYLE_ENABLED
- row_btns_sel_tests = self.STYLE_ENABLED
- ctrl_panel.set({
- "cl-selected-options": self._list_tests(store_sel)
- })
- else:
- row_fig_tput = self.PLACEHOLDER
- row_fig_lat = self.PLACEHOLDER
- row_btn_dwnld = self.PLACEHOLDER
- row_card_sel_tests = self.STYLE_DISABLED
- row_btns_sel_tests = self.STYLE_DISABLED
- store_sel = list()
- ctrl_panel.set({
- "cl-selected-options": list()
- })
if ctrl_panel.get("cl-ctrl-core-value") and \
ctrl_panel.get("cl-ctrl-framesize-value") and \
@@ -1245,7 +1240,10 @@ class Layout:
disabled = False
else:
disabled = True
- ctrl_panel.set({"btn-ctrl-add-disabled": disabled})
+ ctrl_panel.set({
+ "btn-ctrl-add-disabled": disabled,
+ "cl-normalize-value": cl_normalize
+ })
ret_val = [
ctrl_panel.panel, store_sel,
@@ -874,8 +905,8 @@ class Layout:
dd_dut: str, dd_phy: str, dd_area: str, dd_test: str, cl_core: list,
cl_core_all: list, cl_framesize: list, cl_framesize_all: list,
- cl_testtype: list, cl_testtype_all: list, btn_add: int,
- d_start: str, d_end: str, btn_remove: int,
+ cl_testtype: list, cl_testtype_all: list, cl_normalize: list,
+ btn_add: int, d_start: str, d_end: str, btn_remove: int,
btn_remove_all: int, href: str) -> tuple:
"""